.. image:: docs/source/_static/banner.png
   :width: 600
   :align: center
   :alt: Banner

Episuite
=============================
|Development Status| |Run Tests| |PyPi Shield| |Coverage Status|

Welcome to **Episuite**. Episuite is a suite of tools for epidemiology 
in Python.

`Click here for documentation <https://perone.github.io/episuite>`_

*Episuite is currently under development, and accepting contributions.*

.. |Development Status| image:: https://img.shields.io/badge/Development%20Status-2%20--%20Alpha-yellow
.. |Run Tests| image:: https://github.com/perone/episuite/workflows/CI/badge.svg
   :target: https://github.com/perone/episuite/actions?query=workflow%3A%22CI%22+branch%3Amain
.. |PyPi Shield| image:: https://img.shields.io/pypi/v/episuite.svg
   :target: https://pypi.python.org/pypi/episuite
.. |Coverage Status| image:: https://codecov.io/gh/perone/episuite/branch/main/graph/badge.svg?token=XE5J0UX1U4
   :target: https://codecov.io/gh/perone/episuite



